@@ -931,7 +931,7 @@ void IPhreeqc::SetBasicCallback(double (*fcn)(double x1, double x2, const char *
 	this->PhreeqcPtr->register_basic_callback(fcn, cookie1);
 }
 #ifdef IPHREEQC_NO_FORTRAN_MODULE
-void IPhreeqc::SetBasicFortranCallback(double (*fcn)(double *x1, double *x2, char *str, size_t l))
+void IPhreeqc::SetBasicFortranCallback(double (*fcn)(double *x1, double *x2, const char *str, size_t l))
 {
 	this->PhreeqcPtr->register_fortran_basic_callback(fcn);
 }
