@@ -1,11 +1,11 @@
 #define NAME          "IPhreeqc"
 #define VER_MAJOR      3
 #define VER_MINOR      8
-#define VER_PATCH      0
-#define VER_REVISION   16920
-#define GIT_COMMIT     e63b6356326c4c6f1c45f50c22254d3f5eaeb9c7
+#define VER_PATCH      5
+#define VER_REVISION   17066
+#define GIT_COMMIT     7e412da938f8c163004a17d5e30a874a045d541c
 
-#define RELEASE_DATE           "July 11, 2024"
+#define RELEASE_DATE           "December  4, 2024"
 
 #define APR_STRINGIFY(n) APR_STRINGIFY_HELPER(n)
 #define APR_STRINGIFY_HELPER(n) #n
