@@ -8,6 +8,7 @@
 #include <vector>				// std::vector
 
 #include "NumKeyword.h"
+class Dictionary;
 
 class cxxPressure:public cxxNumKeyword
 {
@@ -29,7 +30,9 @@ class cxxPressure:public cxxNumKeyword
 	void Set_count(int i) {count = i;}
 	bool Get_equalIncrements(void) const {return equalIncrements;}
 	void Set_equalIncrements(bool tf) {equalIncrements = tf;}
-
+	void Serialize(Dictionary & dictionary, std::vector < int >&ints, std::vector < double >&doubles);
+	void Deserialize(Dictionary & dictionary, std::vector < int >&ints, std::vector < double >&doubles, int &ii, int &dd);
+	
 protected:
 	std::vector < LDBLE >pressures;
 	int count;
