@@ -28,6 +28,13 @@
 #include "phqalloc.h"
 #include "Use.h"
 
+#if defined(PHREEQCI_GUI)
+#ifdef _DEBUG
+#define new DEBUG_NEW
+#undef THIS_FILE
+static char THIS_FILE[] = __FILE__;
+#endif
+#endif
 
 //////////////////////////////////////////////////////////////////////
 // Construction/Destruction
@@ -802,41 +809,6 @@ cxxStorageBin::Get_Pressures()
 {
 	return this->Pressures;
 }
-#ifdef SKIP
-void
-cxxStorageBin::dump_xml(std::ostream & s_oss, unsigned int indent) const const
-{
-	unsigned int i;
-	s_oss.precision(DBL_DIG - 1);
-	std::string indent0(""), indent1(""), indent2("");
-	for (i = 0; i < indent; ++i)
-		indent0.append(Utilities::INDENT);
-	for (i = 0; i < indent + 1; ++i)
-		indent1.append(Utilities::INDENT);
-	for (i = 0; i < indent + 2; ++i)
-		indent2.append(Utilities::INDENT);
-
-	// StorageBin element and attributes
-	s_oss << indent0;
-	s_oss << "<mix " << "\n";
-
-	s_oss << indent1;
-	s_oss << "pitzer_mix_gammas=\"" << this->
-		pitzer_mix_gammas << "\"" << "\n";
-
-	// components
-	s_oss << indent1;
-	s_oss << "<component " << "\n";
-	for (std::list < cxxStorageBinComp >::const_iterator it =
-		 mixComps.begin(); it != mixComps.end(); ++it)
-	{
-		it->dump_xml(s_oss, indent + 2);
-	}
-
-	return;
-}
-#endif
-
 void
 cxxStorageBin::dump_raw(std::ostream & s_oss, unsigned int indent) const
 {
@@ -1318,258 +1290,6 @@ cxxStorageBin::Clear(void)
 	// Pressure
 	this->Pressures.clear();
 }
-#ifdef SKIP
-cxxSolution *
-cxxStorageBin::mix_cxxSolutions(cxxMix & mixmap)
-{
-/*
- *   mixes solutions based on cxxMix structure, returns new solution
- *   return solution must be freed by calling method
- */
-	LDBLE intensive, extensive;
-	cxxSolution *cxxsoln_ptr, *cxxsoln_ptr1;
-/*
- *   Zero out global solution data
- */
-	cxxsoln_ptr = new cxxSolution(0.0);
-/*
- *   Determine sum of mixing fractions
- */
-	extensive = 0.0;
-
-	std::map < int, LDBLE >*mixcomps = mixmap.comps();
-
-	std::map < int, LDBLE >::const_iterator it;
-	for (it = mixcomps->begin(); it != mixcomps->end(); it++)
-	{
-		extensive += it->second;
-	}
-/*
- *   Add solutions 
- */
-	for (it = mixcomps->begin(); it != mixcomps->end(); it++)
-	{
-		cxxsoln_ptr1 = &((this->Solutions.find(it->first))->second);
-		if (cxxsoln_ptr1 == NULL)
-		{
-			error_string = sformatf(
-					"Solution %d not found in mix_cxxSolutions.", it->first);
-			error_msg(error_string, CONTINUE);
-			phreeqc_ptr-> input_error++;
-			return (NULL);
-		}
-		intensive = it->second / extensive;
-		cxxsoln_ptr->add(*cxxsoln_ptr1, intensive, it->second);
-	}
-	return (cxxsoln_ptr);
-}
-#endif
-
-#ifdef SKIP_OR_MOVE_TO_STRUCTURES
-struct system *
-cxxStorageBin::cxxStorageBin2system(Phreeqc * phreeqc_ptr, int n)
-		//
-		// make a system from storagebin
-		//
-{
-	struct system *system_ptr =
-		(struct system *) phreeqc_ptr-> PHRQ_malloc(sizeof(struct system));
-	if (system_ptr == NULL)
-		phreeqc_ptr-> malloc_error();
-
-	// Solutions
-
-	if (this->getSolution(n) != NULL)
-	{
-		//system_ptr->solution = (this->getSolution(n))->cxxSolution2solution(phreeqc_ptr);
-		system_ptr->solution = phreeqc_ptr-> cxxSolution2solution(this->getSolution(n));
-	}
-	else
-	{
-		system_ptr->solution = NULL;
-	}
-
-	// Exchangers
-	if (this->getExchange(n) != NULL)
-	{
-		//system_ptr->exchange = (this->getExchange(n))->cxxExchange2exchange(phreeqc_ptr);
-		system_ptr->exchange = phreeqc_ptr-> cxxExchange2exchange(this->getExchange(n));
-	}
-	else
-	{
-		system_ptr->exchange = NULL;
-	}
-
-	// GasPhases
-	if (this->getGasPhase(n) != NULL)
-	{
-		//system_ptr->gas_phase = (this->getGasPhase(n))->cxxGasPhase2gas_phase(phreeqc_ptr);
-		system_ptr->gas_phase = phreeqc_ptr-> cxxGasPhase2gas_phase(this->getGasPhase(n));
-	}
-	else
-	{
-		system_ptr->gas_phase = NULL;
-	}
-
-	// Kinetics
-	if (this->getKinetics(n) != NULL)
-	{
-		//system_ptr->kinetics = (this->getKinetics(n))->cxxKinetics2kinetics(phreeqc_ptr);
-		system_ptr->kinetics = phreeqc_ptr-> cxxKinetics2kinetics(this->getKinetics(n));
-		
-	}
-	else
-	{
-		system_ptr->kinetics = NULL;
-	}
-
-	// PPassemblages
-	if (this->getPPassemblage(n) != NULL)
-	{
-		//system_ptr->pp_assemblage =
-		//	(this->getPPassemblage(n))->cxxPPassemblage2pp_assemblage(phreeqc_ptr);
-		system_ptr->pp_assemblage =
-			phreeqc_ptr-> cxxPPassemblage2pp_assemblage(this->getPPassemblage(n));
-	}
-	else
-	{
-		system_ptr->pp_assemblage = NULL;
-	}
-
-	// SSassemblages
-	if (this->getSSassemblage(n) != NULL)
-	{
-		//system_ptr->ss_assemblage =
-		//	(this->getSSassemblage(n))->cxxSSassemblage2ss_assemblage(phreeqc_ptr);
-		system_ptr->ss_assemblage =
-			phreeqc_ptr-> cxxSSassemblage2ss_assemblage((this->getSSassemblage(n)));
-	}
-	else
-	{
-		system_ptr->ss_assemblage = NULL;
-	}
-
-	// Surfaces
-	if (this->getSurface(n) != NULL)
-	{
-		//system_ptr->surface = (this->getSurface(n))->cxxSurface2surface(phreeqc_ptr);
-		system_ptr->surface = phreeqc_ptr-> cxxSurface2surface((this->getSurface(n)));
-	}
-	else
-	{
-		system_ptr->surface = NULL;
-	}
-	return system_ptr;
-}
-#endif
-
-#ifdef SKIP
-cxxExchange *
-cxxStorageBin::mix_cxxExchange(cxxMix & mixmap)
-{
-/*
- *   mixes exchangers based on cxxMix structure, returns new exchanger
- *   return exchanger must be freed by calling method
- */
-	cxxExchange *new_exch_ptr, *old_exch_ptr;
-/*
- *   Zero out global solution data
- */
-	new_exch_ptr = new cxxExchange();
-
-	std::map < int, LDBLE >::const_iterator it_mix;
-	std::map < int, LDBLE >*mixcomps = mixmap.comps();
-
-	// Pitzer_exchange_gammas
-	it_mix = mixcomps->begin();
-	old_exch_ptr = &((this->Exchangers.find(it_mix->first))->second);
-	if (old_exch_ptr == NULL)
-	{
-		error_string = sformatf( "Exchange %d not found in mix_cxxExchange.",
-				it_mix->first);
-		error_msg(error_string, CONTINUE);
-		phreeqc_ptr-> input_error++;
-		return (NULL);
-	}
-	new_exch_ptr->set_pitzer_exchange_gammas(old_exch_ptr->
-											 get_pitzer_exchange_gammas());
-/*
- *   Make list of ExchComps
- */
-	std::vector < cxxExchComp > ec_vector;
-	std::vector < LDBLE >f_vector;
-	//
-	// make list of all exchange components and their mix fractions
-	//
-	for (it_mix = mixcomps->begin(); it_mix != mixcomps->end(); it_mix++)
-	{
-		old_exch_ptr = &((this->Exchangers.find(it_mix->first))->second);
-		if (old_exch_ptr == NULL)
-		{
-			error_string = sformatf( "Exchange %d not found in mix_cxxExchange.",
-					it_mix->first);
-			error_msg(error_string, CONTINUE);
-			phreeqc_ptr-> input_error++;
-			return (NULL);
-		}
-		//  Add exchange components to vector ec_vector
-		std::list < cxxExchComp >::const_iterator it_ec;
-		std::list < cxxExchComp > &eclist = old_exch_ptr->get_exchComps();
-		for (it_ec = eclist.begin(); it_ec != eclist.end(); it_ec++)
-		{
-			f_vector.push_back(it_mix->second);
-			//cxxExchComp ec = *it_ec;
-			//ec_vector.push_back(ec);
-			ec_vector.push_back(*it_ec);
-		}
-	}
-	//
-	// Process list to make mixture
-	//
-	char *current_formula = ec_vector.begin()->get_formula();
-	while (current_formula != NULL)
-	{
-
-		std::vector < cxxExchComp > ec_subvector;
-		std::vector < LDBLE >f_subvector;
-		std::vector < cxxExchComp >::iterator it_ec = ec_vector.begin();
-		std::vector < LDBLE >::iterator it_f = f_vector.begin();
-		current_formula = NULL;
-		for (; it_ec != ec_vector.end(); it_ec++)
-		{
-			if (*it_f != 0)
-			{
-				if (current_formula == NULL)
-					current_formula = it_ec->get_formula();
-				if (it_ec->get_formula() == current_formula)
-				{
-					ec_subvector.push_back(*it_ec);
-					f_subvector.push_back(*it_f);
-					*it_f = 0;
-					//ec_vector.erase(it_ec);
-					//f_vector.erase(it_f);
-				}
-			}
-			it_f++;
-		}
-		//
-		//  mix ec_subvector to make
-		// one exchange component
-		//
-		if (current_formula != NULL)
-		{
-			cxxExchComp new_comp(ec_subvector, f_subvector);
-			new_exch_ptr->get_exchComps().push_back(new_comp);
-		}
-	}
-	/*
-	   std::ostringstream oss;
-	   new_exch_ptr->dump_raw(oss, 0);
-	   std::cerr << oss.str();
-	 */
-	return (new_exch_ptr);
-}
-#endif
 
 cxxSystem &
 cxxStorageBin::Get_System(void)
