@@ -59,7 +59,7 @@
 
 
 #include <stdio.h>
-#include <math.h>
+#include <cmath>
 #include "sundialsmath.h"
 #include "sundialstypes.h"
 
